@@ -22,7 +22,7 @@ module xtb_gfnff_param
    use xtb_gfnff_topology, only : TGFFTopology
    implicit none
    private
-   public :: ini, gff_print, make_chrg, efield
+   public :: ini, gff_print, make_chrg
    public :: gfnff_set_param, gfnff_load_param, gfnff_read_param
    public :: gfnff_param_alloc, gfnff_param_dealloc, gfnff_thresholds
    public :: gffVersion
@@ -43,6 +43,9 @@ module xtb_gfnff_param
       !> Harmonic potential version of the Angew. Chem. 2020
       integer :: harmonic2020 = -1
 
+      !> Periodic Boundary Conditions with Original Parameters
+      integer :: mcgfnff2023 = 4
+
    end type TGFFVersionEnum
 
    !> Actual enumerator for force field versions
@@ -280,7 +283,6 @@ module xtb_gfnff_param
       & 0.500000_wp]
 
 !----------------------------------------------------------------------------------------
-   real(wp) :: efield(3)              ! electric field components
 
    !========================================================================
    ! DATA
@@ -371,7 +373,7 @@ module xtb_gfnff_param
      param%atcuta_nci  = 0.395d0 ! nci angle damping in HB term
      param%atcutt_nci  = 0.305d0 ! nci torsion angle damping in HB term
      param%repscalb= 1.7583      ! bonded rep. scaling
-     param%repscaln= 0.4270      ! non-bonded rep. scaling
+     param%repscaln= 0.4270_wp   ! non-bonded rep. scaling
      param%hbacut   =49.         ! HB angle cut-off
      param%hbscut   =22.         ! HB SR     "   "
      param%xbacut   =70.         ! same for XB
@@ -483,7 +485,8 @@ module xtb_gfnff_param
      param%repz(:) = repz
 
      select case(version)
-     case(gffVersion%angewChem2020, gffVersion%angewChem2020_1, gffVersion%angewChem2020_2, gffVersion%harmonic2020)
+     case(gffVersion%angewChem2020, gffVersion%angewChem2020_1, gffVersion%angewChem2020_2, &
+                     & gffVersion%harmonic2020, gffVersion%mcgfnff2023)
         call loadGFNFFAngewChem2020(param)
         exist = .true.
      end select
@@ -547,38 +550,39 @@ module xtb_gfnff_param
 
    end subroutine gfnff_read_param
 
-   subroutine gfnff_param_alloc(topo, n)
+   subroutine gfnff_param_alloc(topo, neigh, n)
      use xtb_mctc_accuracy, only : wp 
+     use xtb_gfnff_neighbor
      implicit none
 !    Dummy
      type(TGFFTopology), intent(inout) :: topo
+     type(TNeigh), intent(inout) :: neigh
      integer,intent(in) :: n
 
-     if (.not.allocated(topo%nb)) allocate( topo%nb(20,n), source = 0 )
-     if (.not.allocated(topo%bpair)) allocate( topo%bpair(n*(n+1)/2), source = 0 )
-     if (.not.allocated(topo%alphanb)) allocate( topo%alphanb(n*(n+1)/2), source = 0.0d0 )
+     if (.not.allocated(topo%alphanb)) allocate( topo%alphanb(n,n,neigh%numctr+1), source = 0.0d0 )
      if (.not.allocated(topo%chieeq)) allocate( topo%chieeq(n), source = 0.0d0 )
      if (.not.allocated(topo%gameeq)) allocate( topo%gameeq(n), source = 0.0d0 )
      if (.not.allocated(topo%alpeeq)) allocate( topo%alpeeq(n), source = 0.0d0 )
      if (.not.allocated(topo%qa)) allocate( topo%qa(n), source = 0.0d0 )
      if (.not.allocated(topo%zetac6)) allocate( topo%zetac6(n*(n+1)/2), source = 0.0d0 )
      if (.not.allocated(topo%xyze0)) allocate( topo%xyze0(3,n), source = 0.0d0 )
-     if (.not.allocated(topo%b3list)) allocate( topo%b3list(3,1000*n), source = 0 )
+     if (.not.allocated(topo%b3list)) allocate( topo%b3list(5,1000*n), source = 0 )
+     if (.not.allocated(topo%sTorsl)) allocate( topo%sTorsl(6,topo%nstors), source = 0 )
      if (.not.allocated(topo%fraglist)) allocate( topo%fraglist(n), source = 0 )
      if (.not.allocated(topo%qfrag)) allocate( topo%qfrag(n), source = 0.0d0 )
-     if (.not.allocated(topo%hbatHl)) allocate( topo%hbatHl(n), source = 0 )
+     if (.not.allocated(topo%hbatHl)) allocate( topo%hbatHl(2,n), source = 0 )
      if (.not.allocated(topo%hbbas)) allocate( topo%hbbas(n), source = 0.0d0 )
      if (.not.allocated(topo%hbaci)) allocate( topo%hbaci(n), source = 0.0d0 )
      if (.not.allocated(topo%hbatABl)) allocate( topo%hbatABl(2,n*(n+1)/2), source = 0 )
-     if (.not.allocated(topo%xbatABl)) allocate( topo%xbatABl(3,topo%natxbAB), source = 0 )
+     if (.not.allocated(topo%xbatABl)) allocate( topo%xbatABl(5,topo%natxbAB), source = 0 )
 
-     if (.not.allocated(topo%blist)) allocate( topo%blist(2,topo%nbond_blist), source = 0 )
+     if (.not.allocated(neigh%blist)) allocate( neigh%blist(3,neigh%nbond), source = 0 )
      if (.not.allocated(topo%nr_hb)) allocate( topo%nr_hb(topo%nbond_blist), source = 0 )
-     if (.not.allocated(topo%bond_hb_AH)) allocate( topo%bond_hb_AH(2,topo%bond_hb_nr), source = 0 )
-     if (.not.allocated(topo%bond_hb_B)) allocate( topo%bond_hb_B(topo%b_max,topo%bond_hb_nr), source = 0 )
+     if (.not.allocated(topo%bond_hb_AH)) allocate( topo%bond_hb_AH(4,topo%bond_hb_nr), source = 0 )
+     if (.not.allocated(topo%bond_hb_B)) allocate( topo%bond_hb_B(2,topo%b_max,topo%bond_hb_nr), source = 0 )
      if (.not.allocated(topo%bond_hb_Bn)) allocate( topo%bond_hb_Bn(topo%bond_hb_nr), source = 0 )
-     if (.not.allocated(topo%alist)) allocate( topo%alist(3,topo%nangl_alloc), source = 0 )
-     if (.not.allocated(topo%tlist)) allocate( topo%tlist(5,topo%ntors_alloc), source = 0 )
+     if (.not.allocated(topo%alist)) allocate( topo%alist(5,topo%nangl_alloc), source = 0 )
+     if (.not.allocated(topo%tlist)) allocate( topo%tlist(8,topo%ntors_alloc), source = 0 )
      if (.not.allocated(topo%vbond)) allocate( topo%vbond(3,topo%nbond_vbond), source = 0.0d0 )
      if (.not.allocated(topo%vangl)) allocate( topo%vangl(2,topo%nangl_alloc), source = 0.0d0 )
      if (.not.allocated(topo%vtors)) allocate( topo%vtors(2,topo%ntors_alloc), source = 0.0d0 )
@@ -591,8 +595,6 @@ module xtb_gfnff_param
      type(TGFFTopology), intent(inout) :: topo
 !    Dummy
 
-     if (allocated(topo%nb)) deallocate( topo%nb )
-     if (allocated(topo%bpair)) deallocate( topo%bpair )
      if (allocated(topo%alphanb)) deallocate( topo%alphanb )
      if (allocated(topo%chieeq)) deallocate( topo%chieeq )
      if (allocated(topo%gameeq)) deallocate( topo%gameeq )
