@@ -46,7 +46,7 @@ subroutine test_dftd3_pbc3d_neighbourlist(error)
    use xtb_type_environment, only : TEnvironment, init
    use xtb_type_molecule, only : TMolecule, init, len
    use xtb_type_neighbourlist, only : TNeighbourList, init
-   use xtb_type_latticepoint, only : TLatticePoint, init
+   use xtb_type_latticepoint, only : TLatticePoint, init_l
    use xtb_type_param, only : dftd_parameter
 
    use xtb_disp_coordinationnumber, only : getCoordinationNumber, cnType
@@ -132,7 +132,7 @@ subroutine test_dftd3_pbc3d_neighbourlist(error)
    gradient(:, :) = 0.0_wp
    sigma(:, :) = 0.0_wp
 
-   call init(latp, env, mol, 60.0_wp)  ! Fixed cutoff
+   call init_l(latp, env, mol, 60.0_wp)  ! Fixed cutoff
    call latp%getLatticePoints(trans, 60.0_wp)
    call init(neighList, len(mol))
    call neighList%generate(env, mol%xyz, 60.0_wp, trans, .false.)
@@ -229,7 +229,7 @@ subroutine test_dftd3_pbc3d_latticepoints(error)
    use xtb_type_environment, only : TEnvironment, init
    use xtb_type_molecule, only : TMolecule, init, len
    use xtb_type_neighbourlist, only : TNeighbourList, init
-   use xtb_type_latticepoint, only : TLatticePoint, init
+   use xtb_type_latticepoint, only : TLatticePoint, init_l
    use xtb_type_wignerseitzcell, only : TWignerSeitzCell, init
    use xtb_type_param, only : dftd_parameter
 
@@ -321,7 +321,7 @@ subroutine test_dftd3_pbc3d_latticepoints(error)
 !   dcndr(:, :, :) = 0.0_wp
 !   dcndL(:, :, :) = 0.0_wp
 
-   call init(latp, env, mol, 60.0_wp)  ! Fixed cutoff
+   call init_l(latp, env, mol, 60.0_wp)  ! Fixed cutoff
    call latp%getLatticePoints(trans, 40.0_wp)
    call init(neighList, len(mol))
    call neighList%generate(env, mol%xyz, 40.0_wp, trans, .false.)
@@ -420,7 +420,7 @@ subroutine test_dftd3_pbc3d_threebody_neighs(error)
    use xtb_type_environment, only : TEnvironment, init
    use xtb_type_molecule, only : TMolecule, init, len
    use xtb_type_neighbourlist, only : TNeighbourList, init
-   use xtb_type_latticepoint, only : TLatticePoint, init
+   use xtb_type_latticepoint, only : TLatticePoint, init_l
    use xtb_type_wignerseitzcell, only : TWignerSeitzCell, init
    use xtb_type_param, only : dftd_parameter
 
@@ -507,7 +507,7 @@ subroutine test_dftd3_pbc3d_threebody_neighs(error)
    gradient(:, :) = 0.0_wp
    sigma(:, :) = 0.0_wp
 
-   call init(latp, env, mol, 15.0_wp)  ! Fixed cutoff
+   call init_l(latp, env, mol, 15.0_wp)  ! Fixed cutoff
    call latp%getLatticePoints(trans, 15.0_wp)
    call init(neighList, len(mol))
    call neighList%generate(env, mol%xyz, 15.0_wp, trans, .false.)
@@ -596,7 +596,7 @@ subroutine test_dftd3_pbc3d_threebody_latp(error)
    use xtb_type_environment, only : TEnvironment, init
    use xtb_type_molecule, only : TMolecule, init, len
    use xtb_type_neighbourlist, only : TNeighbourList, init
-   use xtb_type_latticepoint, only : TLatticePoint, init
+   use xtb_type_latticepoint, only : TLatticePoint, init_l
    use xtb_type_wignerseitzcell, only : TWignerSeitzCell, init
    use xtb_type_param, only : dftd_parameter
 
@@ -683,7 +683,7 @@ subroutine test_dftd3_pbc3d_threebody_latp(error)
    gradient(:, :) = 0.0_wp
    sigma(:, :) = 0.0_wp
 
-   call init(latp, env, mol, 15.0_wp)  ! Fixed cutoff
+   call init_l(latp, env, mol, 15.0_wp)  ! Fixed cutoff
    call latp%getLatticePoints(trans, 15.0_wp)
    call init(neighList, len(mol))
    call neighList%generate(env, mol%xyz, 15.0_wp, trans, .false.)
